pub enum TemporalError {
TruncatedHeader,
UnsupportedVersion(u32),
InvalidStride(u32),
Io(Error),
Copc(CopcError),
}Expand description
Errors that can occur when reading the temporal index.
Variants
TruncatedHeader
The temporal EVLR header is shorter than 32 bytes.
UnsupportedVersion(u32)
The temporal index version is not supported by this reader.
InvalidStride(u32)
The stride value in the header is invalid.
Io(Error)
I/O error from the underlying byte source.
Copc(CopcError)
Error propagated from the COPC streaming reader.